@@ -257,6 +257,9 @@ function parseToken(data) {
 }
 
 function login(email, password) {
+    error.reason = "";
+    error.state  = "hidden";
+
     try {
         waiting.state = "shown";
         var url = "https://www.google.com/accounts/ClientLogin?Email=" + encodeURIComponent(email) + "&Passwd=" + encodeURIComponent(password) + "&service=finance" + "&source=" + encodeURIComponent("stockona");
@@ -793,7 +796,7 @@ function cleanModel(model) {
 
 // Yahoo return 0 for ask/bid for non-North American exchange
 function convertExchangeForYahoo (name, exg) {
-    console.log(name + exg);
+    //console.log(name + exg);
     if (exg=="NYSE" || exg=="NASDAQ") { return name; }
     else if (exg=="OTC")              { return (name + "." + "OB"); }
     else if (exg=="AMEX")             { return (name + "." + "OB"); }
